##############################################
# Package phenofun
# Automated sROI-approach
# 
# Date: 01.07.16
# Autoren: Ludwig Bothmann
##############################################

################################################################################
# To execute this example code, you need webcam data. See for example 
#   http://www.foto-webcam.eu/ or http://amos.cse.wustl.edu/
# The folder of the webcam data can be specified with "folder_data", see below
################################################################################

rm(list=ls())

# Set working directory according to your folder structure
setwd("xxx")

# Install package phenofun from R-Forge
install.packages("phenofun", repos="http://R-Forge.R-project.org")

# Load package "phenofun"
library(phenofun)
# help(package="phenofun")

# Which parts of the analysis shall be carried out?
get_timeseries <- TRUE
correlate_timeseries <- TRUE
do_evaluation <- TRUE
do_strucchange <- TRUE

# Color channel of interest
color <- "green"

# Name of analyis (for path of results)
name_of_analysis <- "160701"

# Folder of results
folder_results <- "results/"

# Folder of data
folder_data <- "data/"

# Vector with file names of relevant images
lists_files <- list.files(path=folder_data)

# Indices of images to be analyzed
which_images <- c(1001:2441)

# Which image is background image for overlay plots?
which_images_background <- 1500

# Extract DOYs
doy <- as.numeric(substr(lists_files,26,28))

# DOY continous over several years
doy_c <- doy
doy_c[1001:2441] <- doy_c[1001:2441] + 365
doy_c[2442:2466] <- doy_c[2442:2466] + 2*365

# Title for plot
main_camera <- "Location - Year"

# Number of random pinpricks
n_regions <- 10

# Vector with thresholds for correlations
threshold_vec <- seq(.5, .9, by=.05)#length=2)

# Set seed
seed <- 1014

# Dimensions of image
x <- 1285:2560
y <- 1:960

#################################################################
#	Carry out sroi analysis
#################################################################

# Print sessionInfo and save time of start
sessionInfo()
time_start <- Sys.time()

sroi_analysis(get_timeseries=get_timeseries,
              correlate_timeseries=correlate_timeseries,
              do_evaluation=do_evaluation,
              do_strucchange=do_strucchange,
              color=color,
              name_of_analysis=name_of_analysis,
              folder_results=folder_results,
              folder_data=folder_data,
              main_camera=main_camera,
              n_pinpricks=n_regions,
              seed=seed,
              threshold_vec=threshold_vec,
              lists_files=lists_files,
              which_images=which_images,
              doy=doy,
              doy_c=doy_c,
              x=1285:2560,
              y=1:960)

print(gc())
time_end <- Sys.time()
print(time_end - time_start)